;; Generated package description from ivy-avy.el  -*- no-byte-compile: t -*-
(define-package "ivy-avy" "0.14.2.0.20240214.214218" "Avy integration for Ivy" '((emacs "24.5") (ivy "0.14.2") (avy "0.5.0")) :commit "1b63a8f5c2f2dc4c6b3dafbd48d8e3abe96cebca" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Basil L. Contovounesios" . "basil@contovou.net") :keywords '("convenience") :url "https://github.com/abo-abo/swiper")
